@@ -6,13 +6,14 @@ import os.path
 import pathlib
 import shutil
 
-import filelock  # type: ignore
+import filelock
 # `filelock` is also called `py-filelock`.
 # Tried `fasteners` also. In one use case,
 # `filelock` worked whereas `fasteners.InterprocessLock` failed.
 #
 # Other options to look into include
 # `oslo.concurrency`, `pylocker`, `portalocker`.
+from overrides import overrides
 
 from ._upath import Upath, LockAcquisitionTimeoutError, FileInfo
 
@@ -22,7 +23,7 @@ logging.getLogger('filelock').setLevel(logging.WARNING)
 logger = logging.getLogger(__name__)
 
 
-class LocalUpath(Upath):  # pylint: disable=abstract-method
+class LocalUpath(Upath):
     def __init__(self, *pathsegments: str):
         assert os.name == 'posix'
         if pathsegments:
@@ -31,15 +32,18 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
             parts = [str(pathlib.Path.cwd().absolute())]
         super().__init__(*parts)
 
+    @overrides
     def _copy_file(self, target):
         os.makedirs(target.localpath.parent, exist_ok=True)
         shutil.copyfile(self.localpath, target.localpath)
 
-    def export_dir(self, target: Upath, **kwargs):
+    @overrides
+    def export_dir(self, target: Upath, **kwargs) -> int:
         if isinstance(target, LocalUpath):
             return super().export_dir(target, **kwargs)
         return target.import_dir(self, **kwargs)
 
+    @overrides
     def _export_file(self, target: Upath):
         if isinstance(target, LocalUpath):
             self._copy_file(target)
@@ -48,6 +52,7 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
         # file upload.
         target._import_file(self)
 
+    @overrides
     def file_info(self):
         if not self.is_file():
             return
@@ -64,11 +69,13 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
         # then its `ctime` and `mtime` are both updated.
         # My experiments showed that `ctime` and `mtime` are equal.
 
-    def import_dir(self, source: Upath, **kwargs):
+    @overrides
+    def import_dir(self, source: Upath, **kwargs) -> int:
         if isinstance(source, LocalUpath):
             return super().import_dir(source, **kwargs)
         return source.export_dir(self, **kwargs)
 
+    @overrides
     def _import_file(self, source: Upath):
         if isinstance(source, LocalUpath):
             source._copy_file(self)
@@ -77,12 +84,15 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
         # file download.
         source._export_file(self)
 
-    def is_dir(self):
+    @overrides
+    def is_dir(self) -> bool:
         return self.localpath.is_dir()
 
-    def is_file(self):
+    @overrides
+    def is_file(self) -> bool:
         return self.localpath.is_file()
 
+    @overrides
     def iterdir(self):
         try:
             for p in self.localpath.iterdir():
@@ -95,6 +105,7 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
         return pathlib.Path(self._path)
 
     @contextlib.contextmanager
+    @overrides
     def lock(self, *, timeout=None):
         os.makedirs(self.localpath.parent, exist_ok=True)
         lock = filelock.FileLock(str(self.localpath))
@@ -106,14 +117,16 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
         finally:
             lock.release()
 
-    def read_bytes(self):
+    @overrides
+    def read_bytes(self) -> bytes:
         try:
             return self.localpath.read_bytes()
         except (IsADirectoryError, FileNotFoundError) as e:
             raise FileNotFoundError(self) from e
 
-    def remove_dir(self, *, concurrency=None):
-        n = super().remove_dir(concurrency=concurrency)
+    @overrides
+    def remove_dir(self, *, concurrency=None, **kwargs) -> int:
+        n = super().remove_dir(concurrency=concurrency, **kwargs)
 
         def _remove_empty_dir(path):
             for p in path.iterdir():
@@ -125,15 +138,17 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
             _remove_empty_dir(self.localpath)
         return n
 
-    def remove_file(self):
+    @overrides
+    def remove_file(self) -> int:
         try:
             self.localpath.unlink()
             return 1
         except (FileNotFoundError, IsADirectoryError):
             return 0
 
-    def rename_dir(self, target, *, concurrency=None):
-        target_ = super().rename_dir(target, concurrency=concurrency)
+    @overrides
+    def rename_dir(self, target, *, concurrency=None, **kwargs):
+        target_ = super().rename_dir(target, concurrency=concurrency, **kwargs)
 
         def _remove_empty_dir(path):
             k = 0
@@ -150,10 +165,12 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
 
         return target_
 
+    @overrides
     def _rename_file(self, target):
         os.makedirs(target.localpath.parent, exist_ok=True)
         self.localpath.rename(target.localpath)
 
+    @overrides
     def riterdir(self):
         for p in self.iterdir():
             if p.is_file():
@@ -161,7 +178,8 @@ class LocalUpath(Upath):  # pylint: disable=abstract-method
             elif p.is_dir():
                 yield from p.riterdir()
 
-    def write_bytes(self, data: bytes, *, overwrite=False):
+    @overrides
+    def write_bytes(self, data: bytes, *, overwrite=False) -> int:
         if self.localpath.is_file():
             if not overwrite:
                 raise FileExistsError(self)
